@@ -3,6 +3,7 @@ from collections import defaultdict
 import datetime
 import decimal
 import json
+import re
 
 from moto.compat import OrderedDict
 from moto.core import BaseBackend, BaseModel
@@ -115,28 +116,31 @@ class Item(BaseModel):
         }
 
     def update(self, update_expression, expression_attribute_names, expression_attribute_values):
-        ACTION_VALUES = ['SET', 'set', 'REMOVE', 'remove']
-
-        action = None
-        for value in update_expression.split():
-            if value in ACTION_VALUES:
-                # An action
-                action = value
-                continue
-            else:
+        # Update subexpressions are identifiable by the operator keyword, so split on that and
+        # get rid of the empty leading string.
+        parts = [p for p in re.split(r'\b(SET|REMOVE|ADD|DELETE)\b', update_expression) if p]
+        # make sure that we correctly found only operator/value pairs
+        assert len(parts) % 2 == 0, "Mismatched operators and values in update expression: '{}'".format(update_expression)
+        for action, valstr in zip(parts[:-1:2], parts[1::2]):
+            values = valstr.split(',')
+            for value in values:
                 # A Real value
-                value = value.lstrip(":").rstrip(",")
-            for k, v in expression_attribute_names.items():
-                value = value.replace(k, v)
-            if action == "REMOVE" or action == 'remove':
-                self.attrs.pop(value, None)
-            elif action == 'SET' or action == 'set':
-                key, value = value.split("=")
-                if value in expression_attribute_values:
-                    self.attrs[key] = DynamoType(
-                        expression_attribute_values[value])
+                value = value.lstrip(":").rstrip(",").strip()
+                for k, v in expression_attribute_names.items():
+                    value = re.sub(r'{0}\b'.format(k), v, value)
+
+                if action == "REMOVE":
+                    self.attrs.pop(value, None)
+                elif action == 'SET':
+                    key, value = value.split("=")
+                    key = key.strip()
+                    value = value.strip()
+                    if value in expression_attribute_values:
+                        self.attrs[key] = DynamoType(expression_attribute_values[value])
+                    else:
+                        self.attrs[key] = DynamoType({"S": value})
                 else:
-                    self.attrs[key] = DynamoType({"S": value})
+                    raise NotImplementedError('{} update action not yet supported'.format(action))
 
     def update_with_attribute_updates(self, attribute_updates):
         for attribute_name, update_action in attribute_updates.items():
@@ -345,7 +349,6 @@ class Table(BaseModel):
     def query(self, hash_key, range_comparison, range_objs, limit,
               exclusive_start_key, scan_index_forward, index_name=None, **filter_kwargs):
         results = []
-
         if index_name:
             all_indexes = (self.global_indexes or []) + (self.indexes or [])
             indexes_by_name = dict((i['IndexName'], i) for i in all_indexes)
@@ -634,7 +637,8 @@ class DynamoDBBackend(BaseBackend):
 
         return table.scan(scan_filters, limit, exclusive_start_key)
 
-    def update_item(self, table_name, key, update_expression, attribute_updates, expression_attribute_names, expression_attribute_values):
+    def update_item(self, table_name, key, update_expression, attribute_updates, expression_attribute_names,
+                    expression_attribute_values, expected=None):
         table = self.get_table(table_name)
 
         if all([table.hash_key_attr in key, table.range_key_attr in key]):
@@ -652,6 +656,34 @@ class DynamoDBBackend(BaseBackend):
             range_value = None
 
         item = table.get_item(hash_value, range_value)
+
+        if item is None:
+            item_attr = {}
+        elif hasattr(item, 'attrs'):
+            item_attr = item.attrs
+        else:
+            item_attr = item
+
+        if not expected:
+            expected = {}
+
+        for key, val in expected.items():
+            if 'Exists' in val and val['Exists'] is False:
+                if key in item_attr:
+                    raise ValueError("The conditional request failed")
+            elif key not in item_attr:
+                raise ValueError("The conditional request failed")
+            elif 'Value' in val and DynamoType(val['Value']).value != item_attr[key].value:
+                raise ValueError("The conditional request failed")
+            elif 'ComparisonOperator' in val:
+                comparison_func = get_comparison_func(
+                    val['ComparisonOperator'])
+                dynamo_types = [DynamoType(ele) for ele in val[
+                    "AttributeValueList"]]
+                for t in dynamo_types:
+                    if not comparison_func(item_attr[key].value, t.value):
+                        raise ValueError('The conditional request failed')
+
         # Update does not fail on new items, so create one
         if item is None:
             data = {
