@@ -207,7 +207,7 @@ class DynamoHandler(BaseResponse):
         try:
             result = dynamodb_backend2.put_item(
                 name, item, expected, overwrite)
-        except Exception:
+        except ValueError:
             er = 'com.amazonaws.dynamodb.v20111205#ConditionalCheckFailedException'
             return self.error(er)
 
@@ -316,24 +316,26 @@ class DynamoHandler(BaseResponse):
             else:
                 index = table.schema
 
-            key_map = [column for _, column in sorted(
-                (k, v) for k, v in self.body['ExpressionAttributeNames'].items())]
+            reverse_attribute_lookup = dict((v, k) for k, v in
+                                            six.iteritems(self.body['ExpressionAttributeNames']))
 
             if " AND " in key_condition_expression:
                 expressions = key_condition_expression.split(" AND ", 1)
 
-                index_hash_key = [
-                    key for key in index if key['KeyType'] == 'HASH'][0]
-                hash_key_index_in_key_map = key_map.index(
-                    index_hash_key['AttributeName'])
+                index_hash_key = [key for key in index if key['KeyType'] == 'HASH'][0]
+                hash_key_var = reverse_attribute_lookup.get(index_hash_key['AttributeName'],
+                                                            index_hash_key['AttributeName'])
+                hash_key_regex = r'(^|[\s(]){0}\b'.format(hash_key_var)
+                i, hash_key_expression = next((i, e) for i, e in enumerate(expressions)
+                                              if re.search(hash_key_regex, e))
+                hash_key_expression = hash_key_expression.strip('()')
+                expressions.pop(i)
 
-                hash_key_expression = expressions.pop(
-                    hash_key_index_in_key_map).strip('()')
-                # TODO implement more than one range expression and OR
-                # operators
+                # TODO implement more than one range expression and OR operators
                 range_key_expression = expressions[0].strip('()')
                 range_key_expression_components = range_key_expression.split()
                 range_comparison = range_key_expression_components[1]
+
                 if 'AND' in range_key_expression:
                     range_comparison = 'BETWEEN'
                     range_values = [
@@ -474,14 +476,46 @@ class DynamoHandler(BaseResponse):
             'ExpressionAttributeValues', {})
         existing_item = dynamodb_backend2.get_item(name, key)
 
+        if 'Expected' in self.body:
+            expected = self.body['Expected']
+        else:
+            expected = None
+
+        # Attempt to parse simple ConditionExpressions into an Expected
+        # expression
+        if not expected:
+            condition_expression = self.body.get('ConditionExpression')
+            if condition_expression and 'OR' not in condition_expression:
+                cond_items = [c.strip()
+                              for c in condition_expression.split('AND')]
+
+                if cond_items:
+                    expected = {}
+                    exists_re = re.compile('^attribute_exists\((.*)\)$')
+                    not_exists_re = re.compile(
+                        '^attribute_not_exists\((.*)\)$')
+
+                for cond in cond_items:
+                    exists_m = exists_re.match(cond)
+                    not_exists_m = not_exists_re.match(cond)
+                    if exists_m:
+                        expected[exists_m.group(1)] = {'Exists': True}
+                    elif not_exists_m:
+                        expected[not_exists_m.group(1)] = {'Exists': False}
+
         # Support spaces between operators in an update expression
         # E.g. `a = b + c` -> `a=b+c`
         if update_expression:
             update_expression = re.sub(
                 '\s*([=\+-])\s*', '\\1', update_expression)
 
-        item = dynamodb_backend2.update_item(
-            name, key, update_expression, attribute_updates, expression_attribute_names, expression_attribute_values)
+        try:
+            item = dynamodb_backend2.update_item(
+                name, key, update_expression, attribute_updates, expression_attribute_names, expression_attribute_values,
+                expected)
+        except ValueError:
+            er = 'com.amazonaws.dynamodb.v20111205#ConditionalCheckFailedException'
+            return self.error(er)
 
         item_dict = item.to_json()
         item_dict['ConsumedCapacityUnits'] = 0.5
