@@ -76,6 +76,18 @@ class ManagedPolicy(Policy):
         self.attachment_count += 1
         role.managed_policies[self.name] = self
 
+    def detach_from_role(self, role):
+        self.attachment_count -= 1
+        del role.managed_policies[self.name]
+
+    def attach_to_user(self, user):
+        self.attachment_count += 1
+        user.managed_policies[self.name] = self
+
+    def detach_from_user(self, user):
+        self.attachment_count -= 1
+        del user.managed_policies[self.name]
+
 
 class AWSManagedPolicy(ManagedPolicy):
     """AWS-managed policy."""
@@ -120,6 +132,13 @@ class Role(BaseModel):
     def put_policy(self, policy_name, policy_json):
         self.policies[policy_name] = policy_json
 
+    def delete_policy(self, policy_name):
+        try:
+            del self.policies[policy_name]
+        except KeyError:
+            raise IAMNotFoundException(
+                "The role policy with name {0} cannot be found.".format(policy_name))
+
     @property
     def physical_resource_id(self):
         return self.id
@@ -254,8 +273,10 @@ class User(BaseModel):
         self.created = datetime.utcnow()
         self.mfa_devices = {}
         self.policies = {}
+        self.managed_policies = {}
         self.access_keys = []
         self.password = None
+        self.password_reset_required = False
 
     @property
     def arn(self):
@@ -496,6 +517,24 @@ class IAMBackend(BaseBackend):
         policy = arns[policy_arn]
         policy.attach_to_role(self.get_role(role_name))
 
+    def detach_role_policy(self, policy_arn, role_name):
+        arns = dict((p.arn, p) for p in self.managed_policies.values())
+        try:
+            policy = arns[policy_arn]
+            policy.detach_from_role(self.get_role(role_name))
+        except KeyError:
+            raise IAMNotFoundException("Policy {0} was not found.".format(policy_arn))
+
+    def attach_user_policy(self, policy_arn, user_name):
+        arns = dict((p.arn, p) for p in self.managed_policies.values())
+        policy = arns[policy_arn]
+        policy.attach_to_user(self.get_user(user_name))
+
+    def detach_user_policy(self, policy_arn, user_name):
+        arns = dict((p.arn, p) for p in self.managed_policies.values())
+        policy = arns[policy_arn]
+        policy.detach_from_user(self.get_user(user_name))
+
     def create_policy(self, description, path, policy_document, policy_name):
         policy = ManagedPolicy(
             policy_name,
@@ -527,6 +566,24 @@ class IAMBackend(BaseBackend):
 
         return policies, marker
 
+    def list_attached_user_policies(self, user_name, marker=None, max_items=100, path_prefix='/'):
+        policies = self.get_user(user_name).managed_policies.values()
+
+        if path_prefix:
+            policies = [p for p in policies if p.path.startswith(path_prefix)]
+
+        policies = sorted(policies, key=lambda policy: policy.name)
+        start_idx = int(marker) if marker else 0
+
+        policies = policies[start_idx:start_idx + max_items]
+
+        if len(policies) < max_items:
+            marker = None
+        else:
+            marker = str(start_idx + max_items)
+
+        return policies, marker
+
     def list_policies(self, marker, max_items, only_attached, path_prefix, scope):
         policies = self.managed_policies.values()
 
@@ -583,6 +640,10 @@ class IAMBackend(BaseBackend):
         role = self.get_role(role_name)
         role.put_policy(policy_name, policy_json)
 
+    def delete_role_policy(self, role_name, policy_name):
+        role = self.get_role(role_name)
+        role.delete_policy(policy_name)
+
     def get_role_policy(self, role_name, policy_name):
         role = self.get_role(role_name)
         for p, d in role.policies.items():
@@ -772,6 +833,24 @@ class IAMBackend(BaseBackend):
             raise IAMConflictException(
                 "User {0} already has password".format(user_name))
         user.password = password
+        return user
+
+    def get_login_profile(self, user_name):
+        user = self.get_user(user_name)
+        if not user.password:
+            raise IAMNotFoundException(
+                "Login profile for {0} not found".format(user_name))
+        return user
+
+    def update_login_profile(self, user_name, password, password_reset_required):
+        # This does not currently deal with PasswordPolicyViolation.
+        user = self.get_user(user_name)
+        if not user.password:
+            raise IAMNotFoundException(
+                "Login profile for {0} not found".format(user_name))
+        user.password = password
+        user.password_reset_required = password_reset_required
+        return user
 
     def delete_login_profile(self, user_name):
         user = self.get_user(user_name)
